#
# spec file for package lrslib
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dullver	070
%define lname   liblrs-7_0-0
Name:           lrslib
Version:        7.0
Release:        1.1
Summary:        Reverse Search Vertex Enumeration program
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://cgm.cs.mcgill.ca/~avis/C/lrs.html
Source:         http://cgm.cs.mcgill.ca/~avis/C/lrslib/archive/%name-%dullver.tar.gz
Patch1:         lrs-version.diff
Patch2:         lrs-128.diff
Patch3:         lrs-compile.diff
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libtool >= 2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
lrslib is a library for the reverse search algorithm for vertex
enumeration/convex hull problems and comes with a choice of three
arithmetic packages. Input file formats are compatible with the
cddlib package. All computations are done exactly in either
multiple precision or fixed integer arithmetic. Output is not stored
in memory, so even problems with very large output sizes can
sometimes be solved.

%package -n %lname
Summary:        Reverse Search Vertex Enumeration library
Group:          System/Libraries

%description -n %lname
lrslib is a library for the reverse search algorithm for vertex
enumeration/convex hull problems and comes with a choice of three
arithmetic packages. Input file formats are compatible with the
cddlib package. Computations are done in multiprecision
arithmetic.

%package devel
Summary:        Development files for Reverse Search Vertex Enumeration
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
lrslib is a library for the reverse search algorithm for vertex
enumeration/convex hull problems and comes with a choice of three
arithmetic packages.

This subpackage contains libraries and header files for developing
applications that want to make use of lrslib.

%prep
%autosetup -n %name-%dullver -p1

%build
make CFLAGS="%optflags" CXXFLAGS="%optflags" \
	PACKAGE_VERSION="%version" all-shared

%install
%make_install prefix="%_prefix" PACKAGE_VERSION="%version"
# stupid things
if [ "%_lib" != lib ]; then
	mkdir -p "%buildroot/%_libdir"
	mv "%buildroot/%_libdir/../lib"/* "%buildroot/%_libdir/"
fi
chmod a-x COPYING README "%buildroot/%_includedir/lrslib"/*.h

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_bindir/*
%doc COPYING README

%files -n %lname
%defattr(-,root,root)
%_libdir/liblrs-%version.so.0*

%files devel
%defattr(-,root,root)
%_includedir/lrslib/
%_libdir/liblrs.so

%changelog
* Sat Mar 16 2019 Jan Engelhardt <jengelh@inai.de>
- Update to upstream rerelease 7.0
  (replacing tarballs sucks, upstream!)
  - -- lrslib-070~/lrslib.c 2018-06-25 12:30:34.000000000 +0200
  +++ lrslib-070/lrslib.c 2018-10-23 08:22:44.000000000 +0200
* Sat Oct 20 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 7.0
  * hybrid (64bit/128bit/GMP) arithmetic implemented:
  * speedups of roughly 3-5 times (64bit) and 2 times(128bit)
    over GMP for problems using small integers.
  * overflow checking for 64/128 bit arithmetic
  * __int128 (gcc v.4.6.0 or later) and FLINT arithmetic now supported
  * lrsgmp, mplrsgmp uses only GMP arithmetic, same as lrslib-062
  * lrs/redund/mplrs start in 64 bit moving to 128 bit and then
    to gmp arithmetic as necessary.
  * single arithmetic versions of lrs/mplrs available for
    comparison purposes.
  * single arithmetic versions of lrsnash are available with
    overflow checking.
  * plrs is no longer supported
  * removing the -DSAFE option disables overflow checking in
    64/128 bit mode and results are unpredicable if overflow
    occurs.
  * mplrs now prints maximum tree depth at end and supports
    printcobasis option in input files.
- Drop lrs-am.diff (no longer wanted). Add lrs-version.diff
  and lrs-128.diff.
* Sat Jun 23 2018 jengelh@inai.de
- lrs-am.diff: add -lpthread for programs using boost_thread
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 062
  * New command-line options -countonly, -stopafter <n>, -maxbuf <n>.
  * Volume output.
  * Counting statistics on number of jobs, size of L, number of
    times empty changed to longs.
  * Performance improvements for problems with large outputs.
* Sun Mar 27 2016 jengelh@inai.de
- Initial package (version 061) for build.opensuse.org
